@@ -66,7 +66,13 @@ to implement a pattern :
     - `mini_random_MAP` : a portion of the map gonna be random.
     - `my_pattern` : insert your pattern into an empty map.
     - `kind` : insert well know pattern into an empty map, (currenly 5 patterns are available).
-
+        insert well know pattern into an empty map, (currenly 5 patterns are available)
+        - random : choice randomly one of the following map
+        - line {n} : vertical line, if n is given, n cell alive 
+        - glider
+        - lwss : Lightweight spaceship
+        - mwss : Middleweight spaceship
+        - hwss : Heavyweight spaceship
 
 You can also calculate the average time of instancing, using `timeit` function:
 
@@ -106,7 +112,7 @@ from matplotlib.animation import FuncAnimation
 import numpy as np
 import json
 
-from lexicon import *
+from lexicon import lexicon
 
 
 class Map:
@@ -115,7 +121,14 @@ class Map:
                 - `full_random_MAP` : all the map gonna be random.
                 - `mini_random_MAP` : a portion of the map gonna be random.
                 - `my_pattern` : insert your pattern into an empty map
-                - `kind` : insert well know pattern into an empty map, (currenly 5 patterns are available)
+                - `kind` : 
+                    insert well know pattern into an empty map, (currenly 5 patterns are available)
+                    - random : choice randomly one of the following map
+                    - line {n} : vertical line, if n is given, n cell alive 
+                    - glider
+                    - lwss : Lightweight spaceship
+                    - mwss : Middleweight spaceship
+                    - hwss : Heavyweight spaceship
 
         Args:
             size_or_side ((iterable, lenght = 2) or int):
@@ -158,8 +171,8 @@ class Map:
         if seed != None:
             np.random.seed(seed)
 
-        map_ = np.random.randint(0, 2, (self.x, self.y))
-        return map_
+        self.map = np.random.randint(0, 2, (self.x, self.y))
+        return self.map
 
     def mini_random_MAP(self, size_or_side, seed=None):
         """a portion of the map gonna be random.
@@ -201,12 +214,19 @@ class Map:
 
         Args:
             kind (str, optional): 
-            Lexicon of well know pattern, ex 'line 10' is a line of 10 living cell. 
-            Defaults to None.
+                insert well know pattern into an empty map, (currenly 5 patterns are available)
+                - random : choice randomly one of the following map
+                - line {n} : vertical line, if n is given, n cell alive 
+                - glider
+                - lwss : Lightweight spaceship
+                - mwss : Middleweight spaceship
+                - hwss : Heavyweight spaceship            
+                Defaults to None.
 
         Returns:
             map: matrix representing the map
         """
+        
         kind = kind.lower()
 
         if "line" in kind:
@@ -215,17 +235,14 @@ class Map:
             except:
                 n = 10
             pattern = np.array([1]*n).reshape((n, 1))
+            
+        elif kind == "random":
+            from random import choice 
+            pattern = choice(list(lexicon.values()))
 
-        elif "glider" == kind:
-            pattern = glider
-
-        elif "lwss" == kind:
-            pattern = lwss
-        elif "mwss" == kind:
-            pattern = mwss
-        elif "hwss" == kind:
-            pattern = hwss
-
+        else :
+            pattern = lexicon.get(kind,[[1,1],[1,1]])
+            
         self._insert(pattern)
         return self.map
 
@@ -267,7 +284,7 @@ class GameOfLife:
 
     """
 
-    def __init__(self, size_or_side=None, custom_map=None, seed: int = None, frames: int = 500, zoom: float = 10):
+    def __init__(self, size_or_side=None, custom_map=None, seed: int = None, frames: int = 100, zoom: float = 10):
         """initialise the game, by calculating all the frames.
 
 
@@ -291,7 +308,7 @@ class GameOfLife:
 
             frames (int, optional):
             number of frames calculated. 
-            Defaults to 500.
+            Defaults to 100.
 
             zoom (float, optional): 
             allow to create larger plot, if zoom=10 (square matrix) then the figure size will be (5, 5) inch. 
@@ -361,42 +378,38 @@ class GameOfLife:
         return full_map[1:-1, 1:-1]
 
     @staticmethod
-    def _transition_MAT(map):
+    def _neighbours_matrix(map):
         return (map[:-2, :-2] + map[:-2, 1:-1] + map[:-2, 2:] +
                 map[1:-1, :-2]                 + map[1:-1, 2:] +
                 map[2:, :-2] + map[2:, 1:-1] + map[2:, 2:]
                 )
 
     def next_MAP(self, full_map):
-        inner_map = self._inner_MAP(full_map)
-        next_inner_map = self._transition_MAT(self._board_MAP(full_map))
-        next_inner_map[(next_inner_map < 2) |
-                       (next_inner_map > 3)] = 0
-        next_inner_map[next_inner_map == 3] = 1
+        previous_map = self._inner_MAP(full_map)
+        neighbours = self._neighbours_matrix(self._board_MAP(full_map))
 
-        # todo next_inner_map == 2 with out while loop
-        filtre = inner_map == 1
+        neighbours[(neighbours < 2) | (neighbours > 3)] = 0 # death cell
+        neighbours[neighbours == 3] = 1 # new cell / survivals
+                    
+        survivals = (neighbours == 2) & (previous_map == 1)
+        neighbours[survivals] = 1
 
-        for i in range(self.x):
-            for j in range(self.y):
-                bool_ = filtre[i, j]
-                if bool_ and next_inner_map[i, j] == 2:
-                    next_inner_map[i, j] = 1
+        neighbours[neighbours == 2] = 0
 
-        next_inner_map[next_inner_map == 2] = 0
-        self.map[2:-2, 2:-2] = next_inner_map
+        self.map[2:-2, 2:-2] = neighbours
 
         return self.map
 
+
     def set_history(self, full_map):
         self.is_history_avalide = True
         x, y = len(full_map), len(full_map[0])
         history = np.zeros((self.frames, x, y))
-        map_precedente = full_map
+        previous_map = full_map
         history[0, :, :] = full_map
         for i in range(1, self.frames):
-            map_precedente = history[i-1, :, :]
-            history[i, :, :] = self.next_MAP(map_precedente)
+            previous_map = history[i-1, :, :]
+            history[i, :, :] = self.next_MAP(previous_map)
 
         self.history = history
         return history
@@ -459,21 +472,21 @@ class GameOfLife:
             For saving : 
             You need first to install ffmpeg :
             First search : Homebrew website (https://brew.sh/)
-            Copy past the command in a Terminal
+            Copy past the command in a Terminal, press enter.
             Then in a Terminal : brew install ffmpeg
 
         Args:
             interval_between_two_frames (int, optional):
-            Interval_between_two_frames in milisecond. Defaults to 100.
+            Interval between two frames in milisecond. Defaults to 100.
 
             plot (bool, optional): 
             Allow plotting. Defaults to True.
 
             save (bool, optional):
-            Allow save .Defaults to False.
+            Allow save. Defaults to False.
 
             fps (int, optional):  
-            Frames per second if saved.Defaults to 30.
+            Frames per second if saved. Defaults to 30.
 
             file_name (str, optional): 
             file name for saved, must end by ".mp4", ".mov", ".avi", ".flv" or ".wmv", otherwise it's save with ".mp4".
@@ -492,7 +505,7 @@ class GameOfLife:
         # Save :
         # You need first to install ffmpeg :
         # First search : Homebrew website (https://brew.sh/)
-        # Copy past the command in a Terminal
+        # Copy past the command in a Terminal, press enter.
         # Then in a Terminal : brew install ffmpeg
         if save:
             from matplotlib.animation import FFMpegWriter
@@ -584,7 +597,7 @@ def timeit(cls, loop: int = 10, **kw):
             n += 1
             print(f"processing {i / loop * 100:.2f}%")
     print(f"average of {mean(L):.2f}s per loop",
-          "\n", f"Total time : {time()-T_tot:.2f}")
+          "\n", f"Total time : {time()-T_tot:.2f}s")
     return game
 
 
